==> p_ttauto_crawler-0.1.3-py3-none-any.whl: ttauto_crawler/task.py <==
import sys
import os
import time
import requests
import zipfile
import json
from ttauto_crawler import utils
from ttauto_crawler import binary
import shutil
import subprocess
import random
from urllib.parse import *
from PIL import Image
from fake_useragent import UserAgent
import mutagen
from enum import Enum

class C_STATE(Enum):
    WAIT_DOWNLOAD = 0
    DOWNLOADING = 1
    WAIT_TEMPLATE = 2
    TEMPLATEING = 3
    WAIT_UPLOAD = 4
    UPLOADING = 5
    END = 6
    
MAX_DOWNLOADING_COUNT = 5
MAX_PROCESSING_COUNT = 2
MAX_UPLOADING_COUNT = 5

def _configFile():
    thisFileDir = os.path.dirname(os.path.abspath(__file__))
    file = os.path.join(thisFileDir, "task.config")
    if os.path.exists(file) == False:
        with open(file, 'w') as f:
            json.dump([], f)
    datas = []
    with open(file, 'r', encoding='UTF-8') as f:
        datas = json.load(f)
    return datas

# task edit
def push(lock, data):
    lock.acquire()
    datas = _configFile()
    data["state"] = C_STATE.WAIT_DOWNLOAD.value
    datas.append(data)
    _saveTask(datas)
    lock.release()

def _saveTask(datas):
    thisFileDir = os.path.dirname(os.path.abspath(__file__))
    file = os.path.join(thisFileDir, "task.config")
    with open(file, 'w') as f:
        json.dump(datas, f)

def _getTask(state):
    datas = _configFile()
    for it in datas:
        fff = it["state"]
        if it["state"] == state:
            it["state"] = it["state"] + 1
            _saveTask(datas)
            return it
    return None

def _updateTaskToNext(taskItem, state):
    datas = _configFile()
    for it in datas:
        if it["curGroupId"] == taskItem["curGroupId"] and it["state"] == state:
            keys = taskItem.keys()
            for k in keys:
                it[k] = taskItem[k]
            it["state"] = it["state"] + 1
            _saveTask(datas)
            return

# downloading
def canAddDownload(lock):
    lock.acquire()
    c = 0
    datas = _configFile()
    for it in datas:
        if it["state"] <= C_STATE.DOWNLOADING.value:
            c+=1
    lock.release()
    return c < MAX_DOWNLOADING_COUNT
def canDownload(lock):
    lock.acquire()
    c = 0
    datas = _configFile()
    for it in datas:
        if it["state"] == C_STATE.DOWNLOADING.value:
            c+=1
    lock.release()
    return c < MAX_DOWNLOADING_COUNT
def popDownload(lock):
    lock.acquire()
    it = _getTask(C_STATE.WAIT_DOWNLOAD.value)
    lock.release()
    return it
def finishDownload(lock, taskItem):
    lock.acquire()
    _updateTaskToNext(taskItem, C_STATE.DOWNLOADING.value)
    lock.release()

# processing
def canTemplate(lock):
    lock.acquire()
    c = 0
    datas = _configFile()
    for it in datas:
        if it["state"] == C_STATE.TEMPLATEING.value:
            c+=1
    lock.release()
    return c < MAX_PROCESSING_COUNT
def popTemplate(lock):
    lock.acquire()
    it = _getTask(C_STATE.WAIT_TEMPLATE.value)
    lock.release()
    return it
def finishTemplate(lock, taskItem):
    lock.acquire()
    _updateTaskToNext(taskItem, C_STATE.TEMPLATEING.value)
    lock.release()
    
# uploading
def canUpload(lock):
    lock.acquire()
    c = 0
    datas = _configFile()
    for it in datas:
        if it["state"] == C_STATE.UPLOADING.value:
            c+=1
    lock.release()
    return c < MAX_UPLOADING_COUNT
def popUpload(lock):
    lock.acquire()
    it = _getTask(C_STATE.WAIT_UPLOAD.value)
    lock.release()
    return it
def finishUpload(lock, taskItem):
    lock.acquire()
    _updateTaskToNext(taskItem, C_STATE.UPLOADING.value)
    _updateEndTask()
    lock.release()

def _updateEndTask():
    datas = _configFile()
    newDatas = []
    for it in datas:
        if it["state"] < C_STATE.END.value:
            newDatas.append(it)
    _saveTask(newDatas)

==> p_ttauto_crawler-0.1.11-py3-none-any.whl: ttauto_crawler/task.py <==
import sys
import os
import time
import requests
import zipfile
import json
from ttauto_crawler import utils
from ttauto_crawler import binary
import shutil
import subprocess
import random
from urllib.parse import *
from PIL import Image
from fake_useragent import UserAgent
import mutagen
from enum import Enum

class C_STATE(Enum):
    WAIT_DOWNLOAD = 0
    DOWNLOADING = 1
    WAIT_TEMPLATE = 2
    TEMPLATEING = 3
    WAIT_UPLOAD = 4
    UPLOADING = 5
    END = 6
    
MAX_DOWNLOADING_COUNT = 1
MAX_PROCESSING_COUNT = 1
MAX_UPLOADING_COUNT = 1

def _configFile():
    thisFileDir = os.path.dirname(os.path.abspath(__file__))
    file = os.path.join(thisFileDir, "task.config")
    if os.path.exists(file) == False:
        with open(file, 'w') as f:
            json.dump([], f)
    datas = []
    with open(file, 'r', encoding='UTF-8') as f:
        datas = json.load(f)
    return datas

# task edit
def push(lock, data):
    lock.acquire()
    datas = _configFile()
    data["state"] = C_STATE.WAIT_DOWNLOAD.value
    datas.append(data)
    _saveTask(datas)
    lock.release()

def _saveTask(datas):
    thisFileDir = os.path.dirname(os.path.abspath(__file__))
    file = os.path.join(thisFileDir, "task.config")
    with open(file, 'w') as f:
        json.dump(datas, f)

def _getTask(state):
    datas = _configFile()
    for it in datas:
        fff = it["state"]
        if it["state"] == state:
            it["state"] = it["state"] + 1
            _saveTask(datas)
            return it
    return None

def _updateTaskToNext(taskItem, state):
    datas = _configFile()
    for it in datas:
        if it["curGroupId"] == taskItem["curGroupId"] and it["state"] == state:
            keys = taskItem.keys()
            for k in keys:
                it[k] = taskItem[k]
            it["state"] = it["state"] + 1
            _saveTask(datas)
            return

# downloading
def canAddDownload(lock):
    lock.acquire()
    c = 0
    datas = _configFile()
    for it in datas:
        if it["state"] <= C_STATE.WAIT_TEMPLATE.value:
            c+=1
    lock.release()
    return c < MAX_DOWNLOADING_COUNT
def popDownload(lock):
    lock.acquire()
    it = _getTask(C_STATE.WAIT_DOWNLOAD.value)
    lock.release()
    return it
def finishDownload(lock, taskItem):
    lock.acquire()
    _updateTaskToNext(taskItem, C_STATE.DOWNLOADING.value)
    lock.release()

# processing
def canTemplate(lock):
    lock.acquire()
    c = 0
    datas = _configFile()
    for it in datas:
        if it["state"] == C_STATE.TEMPLATEING.value:
            c+=1
    lock.release()
    return c < MAX_PROCESSING_COUNT
def popTemplate(lock):
    lock.acquire()
    it = _getTask(C_STATE.WAIT_TEMPLATE.value)
    lock.release()
    return it
def finishTemplate(lock, taskItem):
    lock.acquire()
    _updateTaskToNext(taskItem, C_STATE.TEMPLATEING.value)
    lock.release()
    
# uploading
def canUpload(lock):
    lock.acquire()
    c = 0
    datas = _configFile()
    for it in datas:
        if it["state"] == C_STATE.UPLOADING.value:
            c+=1
    lock.release()
    return c < MAX_UPLOADING_COUNT
def popUpload(lock):
    lock.acquire()
    it = _getTask(C_STATE.WAIT_UPLOAD.value)
    lock.release()
    return it
def finishUpload(lock, taskItem):
    lock.acquire()
    _updateTaskToNext(taskItem, C_STATE.UPLOADING.value)
    _updateEndTask()
    lock.release()

def _updateEndTask():
    datas = _configFile()
    newDatas = []
    for it in datas:
        if it["state"] < C_STATE.END.value:
            newDatas.append(it)
    _saveTask(newDatas)
